/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2017 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; may be distributed and/or modified under the  *
 * terms of the GNU General Public License version 3 as published by the   *
 * Free Software Foundation and appearing in the file LICENSE_GPLv3        *
 * included in the packaging of this file.                                 *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef LANGUAGE_HEADER
#define LANGUAGE_HEADER

#include <QString>
#include <QVector>
// #include <QStringList>

// QString translateString(const QString& id);
class cTranslator
{
    public:
        bool loadTranslation(const QString fname);
    public:
        static const QString translate(int id);
        static QString engText[];
    private:
        QString convertString(const QString &s);

    private:
        static QVector<QString> translateTable;
};


enum TR_CONSTS {
    _PROG_NAME = 0,
    _NR_CONN, //1
    _SEL_FONT, //2
    _TIMEOUTS, //3
    _RETRIES, //4
    _MAX_RATE, //5
    _MIN_RATE, //6
    _KEEP_ALIVE, //7
    _CANCEL_TIMEOUT, //8
    _CANCEL_SLOW, //9
    _CHECK_DOC_TYPE, //10
    _SPIDER, //11
    _ACCEPT_COOK, //12
    _PARSE_JAVA, //13
    _UPDATE_HACK, //14
    _URL_HACK, //15
    _TOL_REQ, //16
    _FORCE_OLD, //17
    _BROWS_ID, //18
    _OS_ID, //19
    _OP, //20
    _HTML_FOOT, //21
    _STRUCT_TYPE, //22
    _DOS_NAMES, //23
    _NO_ERR_PAG, //24
    _NO_EXTERAL, //25
    _HIDE_PASS, //26
    _HIDE_QUERY, //27
    _NOT_PURGE, //28
    _ISO9660_NAMES, //29
    _BUILD, //30
    _ONLY_EXPERTS, //31
    _PRIM_SCAN, //32
    _TRAVEL_MODE, //33
    _GLOBAL_TRAVEL, //34
    _REWRITE_LINKS, //35
    _USE_CACHE, //36
    _DEBUG_MODE, //37
    _MAX_FROM_ROOT, //38
    _MAX_EXTERNAL, //39
    _MAX_SIZE_HTML, //40
    _MAX_SIZE_NHTML, //41
    _SIZE_LIMIT, //42
    _PAUSE_DOWN, //43
    _MAX_TIME, //44
    _SIZE, //45
    _MAX_CONN_SEC, //46
    _MAX_LINKS, //47
    _ALL_LINKS_MATCH, //48
    _GET_NHTML, //49
    _TEST_LINKS, //50
    _GET_HTML_FIRST, //51
    _MIME_ASSOC, //52
    _FILE_TYPES, //53
    _MIME_ID, //54
    _PROX_ADDR, //55
    _PROX_PORT, //56
    _LOGIN, //57
    _PASS, //58
    _USE_PROXY, //59
    _USE_WILDCARDS, //60
    _CRITERION, //61
    _STRING, //62
    _TIP_GIF, //63
    _CARD_FILTER, //64
    _ADD_SCAN_RULE, //65
    _EXCL_LINKS, //66
    _INCL_LINKS, //67
    _STORE_CACHE, //68
    _NO_REDOWNLOAD, //69
    _CREATE_LOG, //70
    _MAKE_INDEX, //71
    _MAKE_WORD_INDEX, //72
    LISTDEF_1, //73
    LISTDEF_2, //74
    LISTDEF_3, //75
    LISTDEF_4, //76
    LISTDEF_5, //77
    LISTDEF_6, //78
    LISTDEF_7, //79
    LISTDEF_8, //80
    LISTDEF_9, //81
    LISTDEF_10, //82
    LISTDEF_11, //83
    _MOD00, //84
    _MOD01, //85
    _MOD02, //86
    _MOD03, //87
    _MOD04, //88
    _MOD05, //89
    _MOD06, //90
    _OK, //91
    _CANCEL, //92
    _EXIT, //93
    _CLOSE, //94
    _TIPCANCEL, //95
    _TIPOK, //96
    _TIPHELP, //97
    _TIPPREV, //98
    _TIPNEXT, //99
    _HIDEPWD, //100
    _SAVEPROJECT, //101
    _CLOSEPRJ, //102
    _DELETECONF, //103
    _DELETEEMPTYCONF, //104
    _ACTIONNYP, //105
    _ERRORDEL, //106
    _SELRULE, //107
    _ENTER_KEYWORD, //108
    _ADDRULE, //109
    _ENTERKEYWORDS, //110
    _ADD, //111
    _SCANRULEZ, //112
    _EXCL, //113
    _INCL, //114
    _EXAMPLE, //115
    _GIF, //116
    _BLUE, //117
    _MOV, //118
    _CGI, //119
    _CGIBIN, //120
    _SOMEWEBCOM, //121
    _SOMEWEB, //122
    _WWWSOMEWEBCOM, //123
    L_B31, //124
    _WWWTESTCOM, //125
    _ADDEXCL, //126
    _ADDINCL, //127
    _EXISTFILTERS, //128
    _CANCELCHANG, //129
    _SAVECURRENT, //130
    _CLICKCONFIRM, //131
    _NOLOGFILES, //132
    _NOINDEX, //133
    _CLICKTOQUIT, //134
    _BROWSEHTML, //135
    _ENDMIRROR, //136
    _VIEWLOG, //137
    _BROWSEWEBSITE, //138
    _NEWPROJ, //139
    _VIEWERR, //140
    _VIEWREPORT, //141
    _CLOSELOGWINDOW, //142
    _INFOTYPE, //143
    _INFOS, //144
    _FIND, //145
    _FINDWORD, //146
    _INFOLOG, //147
    _WARNERRLOG, //148
    _UNINITOLE, //149
    _CANTFIND, //150
    _CANTCONNECT, //151
    _RECEIVE, //152
    _REQUEST, //153
    _CONNECT, //154
    _SEARCH, //155
    _READY, //156
    _RDY, //157
    _WAITING, //158
    _ERROR, //159
    _RECFILES, //160
    _PARSHTML, //161
    _PURG, //162
    _LCACHE, //163
    _TESTINGLINKS, //164
    _PAUSETOGGLE, //165
    _PAUSED, //166
    _STOPNOW, //167
    _SCANNING, //168
    _WAITTIME, //169
    _TRDATA, //170
    _CONNPROVIDER, //171
    _SECTOSTART, //172
    _MIRRINPROGRESS, //173
    _MIRRFINISHED, //174
    _PROBLOCCURED, //175
    _DURING, //176
    _F21, //177
    _F22, //178
    _MIRROR_ABORTED, //179
    _MIRROR_ERR, //180
    _F23, //181
    _ERRDELETING, //182
    _REALLYQUIT, //183
    _G7, //184
    _G1C, //185
    _G9, //186
    _G10, //187
    _G11, //188
    _G13, //189
    _G14, //190
    _G15, //191
    _PROX_DEFINE, //192
    _G15c, //193
    _PATH, //194
    _SELECTPATH, //195
    _QUIT, //196
    _ABOUT, //197
    _G22, //198
    _G23, //199
    _G24, //200
    _G24b, //201
    _G24c, //202
    _G25, //203
    _G25b, //204
    _FNOTFOUND, //205
    _G26b, //206
    _LOADDEFAULT, //207
    _SAVEDEFAULT, //208
    _RESETDEFAULT, //209
    _G30, //210
    _ACTION, //211
    _G32, //212
    _G32b, //213
    _G33, //214
    _G34, //215
    _DEFINE, //216
    _SET_OPT, //217
    _PREFS_OPT, //218
    _PROJ, //219
    _ADD_URL, //220
    _WEB_ADDR, //221
    _STOPPROG, //222
    _HIBER, //223
    _PAUSEDOWNL, //224
    _PAUSE, //225
    _STOPMIRR, //226
    _MINIMIZE, //227
    _H6, //228
    _H7, //229
    _BYTESSAVED, //230
    _STOP, //231
    _LINKSSCANNED, //232
    _TIME, //233
    _CONNECTIONS, //234
    _RUNNING, //235
    _HIDE, //236
    _TRRATE, //237
    _SKIP, //238
    _INFO, //239
    _FILESWR, //240
    _FILESUP, //241
    _ERRORS, //242
    _ERRS, //243
    _INPROGRESS, //244
    _I1, //245
    _I2, //246
    _I2b, //247
    _I2c, //248
    _I3, //249
    _I4, //250
    _I5b, //251
    _I6, //252
    _I6b, //253
    _I7, //254
    _I8, //255
    _I8b, //256
    _I9, //257
    _I10, //258
    _I11, //259
    _I11b, //260
    _I11c, //261
    _I12, //262
    _I13, //263
    _I15, //264
    _I17, //265
    _I18, //266
    _I19, //267
    _I20, //268
    _I20b, //269
    _I21, //270
    _I22b, //271
    _I22c, //272
    _I23b, //273
    _I24, //274
    _I25, //275
    _I26, //276
    _I27, //277
    _I28, //278
    _I29, //279
    _I1a, //280
    _I1b, //281
    _I1c, //282
    _I1d, //283
    _I1e, //284
    _I1f, //285
    _I1h, //286
    _I1i, //287
    _I1j, //288
    _I1k, //289
    _I1k2, //290
    _I30, //291
    _I30b, //292
    _I32b, //293
    _I34, //294
    _I36, //295
    _I39, //296
    _I41, //297
    _LIMITS, //298
    _IDENTITY, //299
    _I45, //300
    _I47, //301
    _I47b, //302
    _I47f, //303
    _I51, //304
    _SAVE_PREFS, //305
    _SAVE, //306
    _I54, //307
    _I55, //308
    _LINKS, //309
    _EXPERTS, //310
    _FLOWCONTROL, //311
    _BROWSERID, //312
    _IOPT7, //313
    _LOGINDEX, //314
    _PROXY, //315
    _MIMETYPES, //316
    _J2, //317
    _J2b, //318
    _J3, //319
    _J6, //320
    _J7, //321
    _J8, //322
    _J8b, //323
    _J9, //324
    _ADJ, //325
    _SAV_SETTINGS, //326
    _ON_HOLD, //327
    _SHUTD, //328
    _TR_SHED, //329
    _J14, //330
    _J15, //331
    _J16, //332
    _J17, //333
    L_K1, //334
    L_K2, //335
    _VISITPAGE, //336
    L_L1, //337
    L_L2, //338
    _M1, //339
    _M2, //340
    _M3, //341
    _M4, //342
    _M5, //343
    _M6, //344
    _M7, //345
    _M8, //346
    _M9, //347
    L_N1, //348
    _NO, //349
    _OPTIONS, //350
    _PAUSETRANSF, //351
    _MODIFYOPT, //352
    _VIEW_LOG, //353
    _VIEWERRLOG, //354
    _VIEWFILETRANSFERS, //355
    L_O17, //356
    _TOOLBAR, //357
    _STATBAR, //358
    _SPLIT, //359
    _FILE, //360
    _PROGR, //361
    _PREF, //362
    _MIRROR, //363
    _LOG, //364
    _WINDOW, //365
    _HELP, //366
    _LOADDEF, //367
    _SAVEDEF, //368
    _RESETTODEF, //369
    _LOADOPT, //370
    _SAVEOPTAS, //371
    _LANGPREF, //372
    _CONTENTS, //373
    _P17, //374
    _P18, //375
    _P19, //376
    _P20, //377
    _P21, //378
    _P22, //379
    _P23, //380
    _USERDEFSTRUCT, //381
    _Q2, //382
    _Q3, //383
    _R1, //384
    _AUTH, //385
    _R10, //386
    _R11, //387
    _R12, //388
    _R13, //389
    _S1, //390
    _S2, //391
    _S3, //392
    _S4, //393
    _S5, //394
    _S10, //395
    _NEWPROJNAME, //396
    _S11b, //397
    _PROJNAME, //398
    _BASEPATH, //399
    _PROJCAT, //400
    _WORKDIR, //401
    _TYPENEWPROJ, //402
    _NEWPROJECT, //403
    L_T1, //404
    L_T2, //405
    L_T4, //406
    L_T7, //407
    _CAPTURL, //408
    L_T10, //409
    L_T12, //410
    L_T13, //411
    L_T14, //412
    L_U1, //413
    _CATCHURL, //414
    L_V2, //415
    L_V3, //416
    _ABORT, //417
    L_V10, //418
    _DIAL1, //419
    _DIAL2, //420
    _DIAL3, //421
    _DIAL4, //422
    _DIAL5, //423
    _DIAL6, //424
    _DIAL7, //425
    _DIAL8, //426
    _DIAL9, //427
    _DIAL10, //428
    _DIAL11, //429
    _DIAL12, //430
    _DIAL13, //431
    _W4, //432
    _W5, //433
    _W6, //434
    _W7, //435
    _X1, //436
    _X2, //437
    _X3, //438
    _WELCOME, //439
    _OSFWB, //440
    _METADESC, //441
    _METAKEYW, //442
    _URLLIST, //443
    _PREVIOUS, //444
    _NEXT, //445
    _URLS, //446
    _WARNING, //447
    _NOJS, //448
    _THANKYOU, //449
    _CANCLSWND, //450
    _SERVEND, //451
    _FATALERR, //452
    _WRONGURLS, //453
    _HOW_THANK, //454
    _SHARE_LINK, //455
    _REPORT_BUG, //456
    _MAKE_DONATE, //457
    _NOTIFY, //458
    _GETCLIPBOARD, //459
    _DOCUMENTS, //460
    _ARCHIVES, //461
    _IMAGES, //462
    _MULTIMEDIA, //463
    _OPENGUI, //464
    _BROWSEEXISTS, //465
    _STEPBYSTEP, //466
    _TOPROJECTPAGE, //467
    _ABOUTPROG, //468
    _ABOUTQT, //, //469
    _QUEST, //, //470
    _OPENFILE, //471
    _NOURL, //472
    _URLNOTCOMP, //473
    _FILEERR, //474
    _REMOVE, //475
    _SURE, //476
    _ANYDIRNOTEMPTY, //477
    _SAVEFILE, //478
    _LANGUAGE, //, //479
    _STOPQ, //, //480
    _NODIR, //481
    _CREATEERR, //482
    _CANOTCREATEDIR, //483
    _NOPROJ, //484
    _WAITSPECHOUR, //485
    _MIRRWAIT, //, //486
    _ERR, //487
    _YES, //488
    _MAKE_TOPINDEX, //489
    _UNITS, //490
    _OPEN, //491
    _PC_OFF, // 492
    _SHUTDOWN_COUNTER, // 493
    _MAKE_TRANSLATION, // 494
    _BROWS_NAME //495
};


#endif
